--- Guilder: Roster Dumper Module
-- This module allows the user to dump the guild roster to a text box in a delimited format, so that it can be copied and pasted into a spreadsheet
-- @class file
-- @name Modules/Dumper.lua
-- @release 2.0.x

--[[
   Copyright 2009 Christo Kotze (onaforeignshore)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
]]

if select(6, GetAddOnInfo("Guilder_" .. (debugstack():match("[o%.][d%.][u%.]les\\(.-)\\") or ""))) ~= "MISSING" then return end

local Guilder = _G.Guilder
if not Guilder then
  error("Guilder_Dumper requires Guilder")
end
local L = LibStub("AceLocale-3.0"):GetLocale("Guilder")

local DEBUG = Guilder.DEBUG
local expect = Guilder.expect

-- default settings for the addon -------------------------------------------

local DATABASE_DEFAULTS = {
	["sortBy"] = "NAME",
	["delimiter"] = 0,
	["rank"] = true,
	["rankIndex"] = false,
	["level"] = true,
	["class"] = true,
	["note"] = false,
	["officerNote"] = false,
	["timeOffline"] = false
}

-- declare the module -------------------------------------------------------

local Guilder_Dumper = Guilder:NewModule("Dumper", "AceEvent-3.0", "AceHook-3.0")
Guilder_Dumper:SetName(L["Roster Dumper"])
Guilder_Dumper:SetDescription(L["Dumps guild/party/raid information into a comma-delimited format."])
Guilder_Dumper:SetDefaults(DATABASE_DEFAULTS)
if DEBUG then
	Guilder_Dumper:SetIcon([[Interface\AddOns\Guilder\Modules\Dumper\Dumper]])
else
	Guilder_Dumper:SetIcon([[Interface\AddOns\Guilder_Dumper\Dumper]])
end

-- variables ----------------------------------------------------------------

Guilder_Dumper.guildRoster = ""

-- Standard Module Methods --------------------------------------------------

-- Is called when the module is loaded
-- @usage internal use only
function Guilder_Dumper:OnModuleLoaded(module)
	if not self.db.profile.enabled then return end
	local id = module.id
end

-- Is called when the module is enabled
-- @usage internal use only
function Guilder_Dumper:OnEnable()
end

-- Is called when the module is disabled
-- @usage internal use only
function Guilder_Dumper:OnDisable()
end

--[[
-- Is called when the user opens the configuration screen
-- @usage internal use only
function Guilder_Dumper:UpdateConfigOptions()
end

-- Is called when the module receives a message
-- @usage internal use only
function Guilder_Dumper:CommHandler(distribution, sender, command, ...)
end
]]

-- General functions --------------------------------------------------------

-- Generates a delimited guild list and puts it in a text box for the user to copy and paste into a spreadsheet
-- @usage internal use only
function Guilder_Dumper:GenerateList()
	-- if module is disabled, do nothing
	if not self.db.profile.enabled then
		Guilder:ShowMessage(L["%s is disabled"]:format("|cff00c0ff"..L["Roster Dumper"].."|r"))
		return
	end
	-- if we're not in a guild, say so
	if not IsInGuild() then
		Guilder:ShowMessage("|cff00c0ff"..L["Roster Dumper"].."|r: "..L["You are not in a guild!"])
		return
	end
	-- create title line
	local member = "Player"
	local delim = (self.db.profile.delimiter == 0) and "," or "\t"
	if self.db.profile.rank then member = member..delim.."Rank" end
	if self.db.profile.rankIndex then member = member..delim.."Rank Index" end
	if self.db.profile.level then member = member..delim.."Level" end
	if self.db.profile.class then member = member..delim.."Class" end
	if self.db.profile.note then member = member..delim.."Note" end
	if self.db.profile.officerNote then member = member..delim.."Officer Note" end
	if self.db.profile.timeOffline then member = member..delim.."Time Offline" end
	-- add to list
	local roster = member.."\n"
	-- create the rest of the list
	for i in LibGuild:GetIterator(self.db.profile.sortBy, true) do
		member = i
		if self.db.profile.rank then member = member..delim..LibGuild:GetRank(i) end
		if self.db.profile.rankIndex then member = member..delim..LibGuild:GetRankIndex(i) end
		if self.db.profile.level then member = member..delim..LibGuild:GetLevel(i) end
		if self.db.profile.class then member = member..delim..LibGuild:GetClass(i) end
		if self.db.profile.note then member = member..delim..(LibGuild:GetNote(i) or "") end
		if self.db.profile.officerNote then member = member..delim..(LibGuild:GetOfficerNote(i) or "") end
		if self.db.profile.timeOffline then member = member..delim..(LibGuild:GetSecondsOffline(i) or "") end
		roster = roster..member.."\n"
	end
	self.guildRoster = roster
	Guilder:ShowMessage("|cff00c0ff"..L["Roster Dumper"].."|r: "..L["Dump complete!"])
	LibStub("AceConfigRegistry-3.0"):NotifyChange("Guilder")
end
